@@ -6,6 +6,7 @@
 from tina4_python.Constant import LOOKUP_HTTP_CODE
 from tina4_python.Debug import Debug
 from http.server import BaseHTTPRequestHandler
+from tina4_python.Constant import  *
 from urllib.parse import urlparse, parse_qsl
 import socket
 import asyncio
@@ -16,9 +17,13 @@ class Webserver:
         params = dict(parse_qsl(urlparse(self.path).query, keep_blank_values=True))
         request = {"params": params, "raw": self.request}
         response = await self.router_handler.resolve(method, self.path, request, self.headers)
-        print("Response", response)
+
         headers = []
-        self.send_header("Content-type", response["content_type"], headers)
+        self.send_header("Content-Type", response["content_type"], headers)
+        self.send_header("Content-Length", str(len(response["content"])), headers)
+        self.send_header("Connection", "Keep-Alive", headers)
+        self.send_header("Keep-Alive", "timeout=5, max=30", headers)
+
         headers = await self.get_headers(headers, self.response_protocol, response["http_code"])
         if type(response["content"]) == str:
             return headers + response["content"].encode()
@@ -35,7 +40,8 @@ class Webserver:
         headers = response_protocol + " " + str(response_code) + " " + LOOKUP_HTTP_CODE[
             response_code] + "\n"
         for header in response_headers:
-            headers += header + "\n\n"
+            headers += header + "\n"
+        headers += "\n"
         print("Headers", headers)
         return headers.encode()
 
@@ -61,12 +67,24 @@ class Webserver:
         # Decode the request
 
         self.request = request.strip()
-        self.path = request.split(" ")[1].strip("\r")
+
+        self.path = request.split(" ")
+
+        if len(self.path) > 1:
+            self.path = request.split(" ")[1].strip("\r")
+
         self.method = request.split(" ")[0].strip("\r")
 
         self.headers = request.split("\n")
-        response = await self.get_response(self.method)
-        await loop.sock_sendall(client, response)
+
+        method_list = [TINA4_GET, TINA4_ANY, TINA4_POST, TINA4_PATCH]
+
+        contains_method = [ele for ele in method_list if(ele in self.method)]
+
+        if self.method != "" and contains_method:
+            response = await self.get_response(self.method)
+            await loop.sock_sendall(client, response)
+
         client.close()
 
     def __init__(self, host_name, port):
